@@ -413,6 +413,18 @@ ggcoef_table <- function(
   }
 
   if ("group_by" %in% colnames(data)) {
+    x_limits <- args$x_limits
+    if (is.null(x_limits)) {
+      if (all(c("conf.low", "conf.high") %in% names(data)))
+        x_limits <- range(
+          data$estimate,
+          data$conf.low,
+          data$conf.high,
+          na.rm = TRUE
+        )
+      else
+        x_limits <- range(data$estimate, na.rm = TRUE)
+    }
     d <- data |>
       tidyr::nest(.by = dplyr::all_of("group_by"))
     res <- purrr::map2(
@@ -444,7 +456,8 @@ ggcoef_table <- function(
         table_text_size = table_text_size,
         table_stat_label = table_stat_label,
         ci_pattern = ci_pattern,
-        table_widths = table_widths
+        table_widths = table_widths,
+        x_limits = x_limits
       )
     ) |> patchwork::wrap_plots(ncol = 1)
     return(res)
@@ -760,6 +773,9 @@ ggcoef_faceted <- function(
 #' @export
 #' @param models named list of models
 #' @param type a dodged plot, a faceted plot or multiple table plots?
+#' @note
+#' `ggcoef_compare(type = "table")` is not compatible with multi-components
+#' models.
 #' @examples
 #' \donttest{
 #' # Use ggcoef_compare() for comparing several models on the same plot
@@ -774,6 +790,7 @@ ggcoef_faceted <- function(
 #'
 #' ggcoef_compare(models)
 #' ggcoef_compare(models, type = "faceted")
+#' ggcoef_compare(models, type = "table")
 #'
 #' # you can reverse the vertical position of the point by using a negative
 #' # value for dodged_width (but it will produce some warnings)
@@ -781,7 +798,7 @@ ggcoef_faceted <- function(
 #' }
 ggcoef_compare <- function(
     models,
-    type = c("dodged", "faceted"),
+    type = c("dodged", "faceted", "table"),
     tidy_fun = broom.helpers::tidy_with_broom_or_parameters,
     tidy_args = NULL,
     conf.int = TRUE,
@@ -802,6 +819,12 @@ ggcoef_compare <- function(
     emmeans_args = list(),
     significance = 1 - conf.level,
     significance_labels = NULL,
+    table_stat = c("estimate", "ci", "p.value"),
+    table_header = NULL,
+    table_text_size = 3,
+    table_stat_label = NULL,
+    ci_pattern = "{conf.low}, {conf.high}",
+    table_widths = c(3, 2),
     return_data = FALSE,
     ...) {
   data <- lapply(
@@ -867,6 +890,24 @@ ggcoef_compare <- function(
 
   type <- match.arg(type)
 
+  if (type == "table") {
+    data$group_by <- data$model
+    data <- data[!is.na(data$estimate), ]
+    return(
+      ggcoef_table(
+        data = data,
+        ...,
+        exponentiate = exponentiate,
+        table_stat = table_stat,
+        table_header = table_header,
+        table_text_size = table_text_size,
+        table_stat_label = table_stat_label,
+        ci_pattern = ci_pattern,
+        table_widths = table_widths
+      )
+    )
+  }
+
   args <- list(...)
   args$data <- data
   args$exponentiate <- exponentiate
@@ -1042,6 +1083,7 @@ ggcoef_data <- function(
 #'   if labels are too long, you can use [ggplot2::label_wrap_gen()] (see
 #'   examples), more information in the documentation of [ggplot2::facet_grid()]
 #' @param plot_title an optional plot title
+#' @param x_limits optional limits for the x axis
 #' @seealso `vignette("ggcoef_model")`
 #' @export
 ggcoef_plot <- function(
@@ -1074,7 +1116,8 @@ ggcoef_plot <- function(
     facet_row = "var_label",
     facet_col = NULL,
     facet_labeller = "label_value",
-    plot_title = NULL) {
+    plot_title = NULL,
+    x_limits = NULL) {
 
   if (!is.null(facet_row)) {
     data[[facet_row]] <- .in_order(data[[facet_row]])
@@ -1140,19 +1183,21 @@ ggcoef_plot <- function(
   if (errorbar) {
     if (!is.null(colour) && errorbar_coloured) {
       p <- p +
-        ggplot2::geom_errorbarh(
+        ggplot2::geom_errorbar(
           na.rm = TRUE,
-          height = errorbar_height,
-          position = position
+          width = errorbar_height,
+          position = position,
+          orientation = "y"
         )
     } else {
       p <- p +
-        ggplot2::geom_errorbarh(
+        ggplot2::geom_errorbar(
           mapping = ggplot2::aes(colour = NULL),
           na.rm = TRUE,
-          height = errorbar_height,
+          width = errorbar_height,
           colour = "black",
-          position = position
+          position = position,
+          orientation = "y"
         )
     }
   }
@@ -1236,7 +1281,9 @@ ggcoef_plot <- function(
   }
 
   if (exponentiate) {
-    p <- p + ggplot2::scale_x_log10()
+    p <- p + ggplot2::scale_x_log10(limits = x_limits)
+  } else {
+    p <- p + ggplot2::scale_x_continuous(limits = x_limits)
   }
 
   if (!is.null(attr(data, "coefficients_label"))) {
