@@ -49,6 +49,7 @@
 #'   scale_fill_steps2(breaks = c(-3, -2, 2, 3), show.limits = TRUE) +
 #'   scale_size_area(max_size = 20)
 #'
+#' \donttest{
 #' # custom shape and fill colour based on phi coeffients
 #' ggplot(d) +
 #'   aes(
@@ -80,6 +81,7 @@
 #'   facet_grid(Sex ~ .) +
 #'   labs(fill = "Standardized residuals") +
 #'   theme_minimal()
+#' }
 stat_cross <- function(mapping = NULL, data = NULL,
                        geom = "point", position = "identity",
                        ...,
@@ -160,7 +162,7 @@ StatCross <- ggplot2::ggproto(
       all.x = TRUE
     )
 
-    panel <- panel %>% dplyr::distinct(.data$x, .data$y, .keep_all = TRUE)
+    panel <- panel |> dplyr::distinct(.data$x, .data$y, .keep_all = TRUE)
 
     if (!keep.zero.cells) {
       panel <- panel[panel$observed != 0, ]
@@ -197,18 +199,19 @@ StatCross <- ggplot2::ggproto(
 #' tab <- xtabs(Freq ~ Sex + Class, data = as.data.frame(Titanic))
 #' augment_chisq_add_phi(chisq.test(tab))
 augment_chisq_add_phi <- function(x) {
-  if (!inherits(x, "htest") && names(x$statistic) != "X-squared")
+  if (!inherits(x, "htest") && names(x$statistic) != "X-squared") {
     cli::cli_abort(paste(
       "{.arg x} should be the result of a chi-squared test",
-      "(see {.fn stats::chisq.test}).")
-    )
+      "(see {.fn stats::chisq.test})."
+    ))
+  }
 
-  broom::augment(x) %>%
-    dplyr::group_by(dplyr::across(1)) %>%
-    dplyr::mutate(.row.observed = sum(.data$.observed)) %>%
-    dplyr::group_by(dplyr::across(2)) %>%
-    dplyr::mutate(.col.observed = sum(.data$.observed)) %>%
-    dplyr::ungroup() %>%
+  broom::augment(x) |>
+    dplyr::group_by(dplyr::across(1)) |>
+    dplyr::mutate(.row.observed = sum(.data$.observed)) |>
+    dplyr::group_by(dplyr::across(2)) |>
+    dplyr::mutate(.col.observed = sum(.data$.observed)) |>
+    dplyr::ungroup() |>
     dplyr::mutate(
       .total.observed = sum(.data$.observed),
       .phi = .compute_phi(
